@@ -1,7 +1,7 @@
 add4ci <-
-function(x,n,conflev){
+function(x,n,conf.level){
    ptilde = (x+2)/(n+4)
-   z = abs(qnorm((1-conflev)/2))
+   z = abs(qnorm((1-conf.level)/2))
    stderr = sqrt(ptilde * (1-ptilde)/(n+4))
    ul = ptilde + z * stderr
    ll = ptilde - z * stderr
